summaryrefslogtreecommitdiff
path: root/src/modinfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/modinfo.h')
-rw-r--r--src/modinfo.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/modinfo.h b/src/modinfo.h
index d611fa87..2c108378 100644
--- a/src/modinfo.h
+++ b/src/modinfo.h
@@ -319,11 +319,11 @@ public:
virtual void setNotes(const QString &notes) = 0;
/**
- * @brief set/change the game plgin for this mod
- *
- * @param gamePlugin the game plugin
- */
- virtual void setGamePlugin(const MOBase::IPluginGame* gamePlugin) = 0;
+ * @brief set/change the source game of this mod
+ *
+ * @param gameName the source game shortName
+ */
+ virtual void setGameName(const QString& gameName) = 0;
/**
* @brief set the name of this mod